@@ -214,9 +214,7 @@ class BaseCli(dnf.Base):
             elif 'test' in self.conf.tsflags:
                 logger.info(_("{prog} will only download packages, install gpg keys, and check the "
                               "transaction.").format(prog=dnf.util.MAIN_PROG_UPPER))
-            if dnf.util._is_bootc_host() and \
-                    os.path.realpath(self.conf.installroot) == "/" and \
-                    not self.conf.downloadonly:
+            if dnf.util._is_bootc_host():
                 _bootc_host_msg = _("""
 *** Error: system is configured to be read-only; for more
 *** information run `bootc --help`.
@@ -331,7 +329,7 @@ class BaseCli(dnf.Base):
     def format_changelog(self, changelog):
         """Return changelog formatted as in spec file"""
         chlog_str = '* %s %s\n%s\n' % (
-            changelog['timestamp'].strftime("%a %b %d %X %Y"),
+            changelog['timestamp'].strftime("%c"),
             dnf.i18n.ucd(changelog['author']),
             dnf.i18n.ucd(changelog['text']))
         return chlog_str
