@@ -3,11 +3,10 @@
 # Copyright (c) 2019 Red Hat, Inc.
 # Copyright (c) 2019 Tomáš Mráz <tmraz@fedoraproject.org>
 
-from tempfile import mkstemp
-
 import os
 import re
 import subprocess
+from tempfile import mkstemp
 
 from .configgenerator import ConfigGenerator
 
@@ -88,7 +87,7 @@ class OpenSSHGenerator(ConfigGenerator):
 
     sign_map = {
         'RSA-SHA1': 'ssh-rsa',
-        'DSA-SHA1': 'ssh-dss',
+        'DSA-SHA1': '',  # openssh no longer recognizes it
         'RSA-SHA2-256': 'rsa-sha2-256',
         'RSA-SHA2-512': 'rsa-sha2-512',
         'ECDSA-SHA2-256': 'ecdsa-sha2-nistp256',
@@ -101,7 +100,7 @@ class OpenSSHGenerator(ConfigGenerator):
 
     sign_map_certs = {
         'RSA-SHA1': 'ssh-rsa-cert-v01@openssh.com',
-        'DSA-SHA1': 'ssh-dss-cert-v01@openssh.com',
+        'DSA-SHA1': '',  # openssh no longer recognizes it
         'RSA-SHA2-256': 'rsa-sha2-256-cert-v01@openssh.com',
         'RSA-SHA2-512': 'rsa-sha2-512-cert-v01@openssh.com',
         'ECDSA-SHA2-256': 'ecdsa-sha2-nistp256-cert-v01@openssh.com',
@@ -200,6 +199,7 @@ class OpenSSHGenerator(ConfigGenerator):
             if do_host_key:
                 cfg += f'HostKeyAlgorithms {s}\n'
             cfg += f'PubkeyAcceptedAlgorithms {s}\n'
+            cfg += f'HostbasedAcceptedAlgorithms {s}\n'
 
         s = ''
         for i in p['sign']:
@@ -212,9 +212,7 @@ class OpenSSHGenerator(ConfigGenerator):
             cfg += f'CASignatureAlgorithms {s}\n'
 
         if policy.integers['min_rsa_size'] > 0:
-            min_rsa_optname = _min_rsa_size_option()
-            if min_rsa_optname is not None:
-                cfg += f"{min_rsa_optname} {policy.integers['min_rsa_size']}\n"
+            cfg += f"RequiredRSASize {policy.integers['min_rsa_size']}\n"
 
         return cfg
 
@@ -238,9 +236,6 @@ class OpenSSHClientGenerator(OpenSSHGenerator):
         if not os.access('/usr/bin/ssh', os.X_OK):
             return True
 
-        if os.getenv('OPENSSH_MIN_RSA_SIZE_FORCE') == '1':
-            config = re.sub(f'{_min_rsa_size_option()}.*', '', config)
-
         fd, path = mkstemp()
 
         ret = 255
@@ -304,9 +299,6 @@ class OpenSSHServerGenerator(OpenSSHGenerator):
         if not os.access('/usr/sbin/sshd', os.X_OK):
             return True
 
-        if os.getenv('OPENSSH_MIN_RSA_SIZE_FORCE') == '1':
-            config = re.sub(f'{_min_rsa_size_option()}.*', '', config)
-
         host_key_filename = cls._test_setup()
         if not host_key_filename:
             return False
@@ -344,16 +336,3 @@ def _openssh_version():
     except (FileNotFoundError, PermissionError):
         return None
     return None
-
-
-def _min_rsa_size_option():
-    MIN_RSA_DEFAULT = 'RequiredRSASize'
-    min_rsa_size_force = os.getenv('OPENSSH_MIN_RSA_SIZE', MIN_RSA_DEFAULT)
-    if min_rsa_size_force == 'none':
-        return None
-    elif min_rsa_size_force == 'auto':
-        openssh_version = _openssh_version()
-        if openssh_version and openssh_version > (9, 0):
-            return 'RequiredRSASize'
-        return None
-    return min_rsa_size_force
